@@ -51,7 +51,7 @@ class Command(BaseCommand):
             'title': f'{base_title} ({env.upper()})',
         }
         env_themes = payla_utils_settings.ENV_THEMES
-        theme: Theme = Theme.objects.filter(active=True).first()
+        theme: Theme = Theme.get_active_theme()
         theme_settings.update(env_themes[env.lower()])
         # update theme name if set to APP_NAME key
         if theme_settings['title'] == 'APP_NAME':
